@@ -1,6 +1,6 @@
 """
-GUI framework implementations
-=============================
+GUI framework demo implementations
+==================================
 
 This module is used as showcase base for the implementation of demo
 applications of the GUI framework packages provided
@@ -15,10 +15,12 @@ ae namespace):
   `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`__
 * :mod:`Enaml <ae.enaml_app>` based on `the enaml framework <https://enaml.readthedocs.io/en/latest/>`__:
   `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__
-* :mod:`Beeware Toga <ae.toga_app>` based on `the beeware/toga framework <https://beeware.org>`__:
+* :mod:`Beeware Toga <ae.toga_app>` based on `the beeware framework <https://beeware.org>`__:
+  `beeware toga lisz demo app <https://gitlab.com/ae-group/toga_lisz>`__
+* :mod:`Dabo <ae.dabo_app>` based on `the dabo framework <https://dabodev.com/>`__:
+  `dabo lisz demo app <https://gitlab.com/ae-group/dabo_lisz>`__
 * :mod:`pyglet <ae.pyglet_app>`
 * :mod:`pygobject <ae.pygobject_app>`
-* :mod:`Dabo <ae.dabo_app>`
 * :mod:`AppJar <ae.appjar_app>`
 
 The main app base mixin class :class:`LiszDataMixin` provided by this module
@@ -74,7 +76,7 @@ Each `LiszItem` element of the tree structure is either a
 leaf or a node. And each node is a sub-list with a recursive
 structure identical to the root node and of the type `LiszNode`.
 
-The following graph is showing an example tree:
+The following graph is showing an example data tree:
 
 .. graphviz::
 
@@ -114,6 +116,12 @@ a `pypi package <https://pypi.org/project/Kivy/>`__
 documented `here <https://kivy.org/doc/stable/>`__.
 
 
+kivy wish list
+______________
+
+* kv language looper pseudo widget (like enaml is providing) for to easily generate sets of similar widgets.
+
+
 enaml
 -----
 
@@ -141,8 +149,8 @@ https://stackoverflow.com/questions/20380940/how-to-get-key-events-when-using-en
 and more complete implementation can be found in the enamlx package (https://github.com/frmdstryr/enamlx).
 
 
-wish list
-_________
+enaml wish list
+_______________
 
 * type and syntax checking, code highlighting and debugging of enaml files within PyCharm.
 * fix freezing of linux/Ubuntu system in debugging of opening/opened PopupViews in PyCharm
@@ -155,7 +163,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.0.10'
+__version__ = '0.0.11'
 
 
 FLOW_PATH_ROOT_ID = '<<<root>>>'     #: needed for flow path jumper and for drop onto leave item button
@@ -386,8 +394,11 @@ class LiszDataMixin(ABC):
             current_node_items = item['node']
         return current_node_items
 
-    def flow_path_quick_jump_nodes(self):
-        """ determine nodes relative to the current flow path to quick-jump to from current node. """
+    def flow_path_quick_jump_nodes(self) -> List[str]:
+        """ determine nodes relative to the current flow path to quick-jump to from current node.
+
+        :return:                list of flow path texts.
+        """
         def append_nodes(node):
             """ recursively collect all available nodes (possible flow paths) """
             for nid in node:
@@ -503,9 +514,10 @@ class LiszDataMixin(ABC):
         """ initialize self.current_node_items from flow_id/flow_path saved on last app stop. """
         self.refresh_current_node_items_from_flow_path()
 
-    def on_app_states_save(self, app_state):
+    def on_app_state_root_node_save(self, root_node: LiszNode) -> LiszNode:
         """ shrink root_node app state variable before it get saved to the config file. """
-        self.shrink_node_size(app_state['root_node'])
+        self.shrink_node_size(root_node)
+        return root_node
 
     def on_filter_toggle(self, toggle_attr: str, _event_kwargs: Dict[str, Any]) -> bool:
         """ toggle filter on click of either the selected or the unselected filter button.
@@ -699,20 +711,19 @@ class LiszDataMixin(ABC):
         self.current_node_items = self.flow_path_node()
 
     def shrink_node_size(self, node: LiszNode):
-        """ shrink size of node and sub-node keys by removing unneeded `sel` keys.
+        """ shrink size of node and sub-node keys by removing unneeded `sel` keys, for to save space in config file.
 
         :param node:            start or root node to shrink.
         """
         for item in node:
-            if 'node' in item:
-                item.pop('sel', None)
-                self.shrink_node_size(item['node'])
-            elif item.get('sel', 1) != 1:
+            if item.get('sel', 1) != 1:
                 item.pop('sel')
             elif 'sel' in item:
-                item['sel'] = 1     # remove also decimal point and zero (float to int)
+                item['sel'] = 1  # remove also decimal point and zero (float to int)
+            if 'node' in item:
+                self.shrink_node_size(item['node'])
 
-    def sub_item_ids(self, item_id, node_only, node=None, sub_item_ids=None):
+    def sub_item_ids(self, item_id, node_only, node=None, sub_item_ids=None) -> List[str]:
         """ return item names of all items including their sub-node items (if exists).
 
         Used for to determine the affected items if user want to delete the item specified by item_id.
